# Worlds
kongo_jungle = "Kongo Jungle Access"
monkey_mines = "Monkey Mines Access"
vine_valley = "Vine Valley Access"
gorilla_glacier = "Gorilla Glacier Access"
kremkroc_industries = "Kremkroc Industries Inc. Access"
chimp_caverns = "Chimp Caverns Access"

# Unlockables
donkey = "Donkey"
diddy = "Diddy"
carry = "Carry"
swim = "Swim"
roll = "Roll"
climb = "Climb"
slap = "Gorilla Slap"
kannons = "Barrel Kannons"
switches = "Switch Barrels"
minecart = "Minecart"
winky = "Winky"
expresso = "Expresso"
rambi = "Rambi"
enguarde = "Enguarde"
squawks = "Squawks"
tires = "Tires"
platforms = "Platforms"

# Collectibles
boss_token = "Big Banana"

# Junk
red_balloon = "1-Up Balloon"
dk_barrel = "Backup DK Barrel"

# Traps
nut_trap = "Nut Trap"
army_trap = "Army Trap"
jump_trap = "Jump Trap"
bonus_trap = "Animal Bonus Trap"
sticky_floor_trap = "Sticky Floor Trap"
ice_trap = "Ice Trap"
stun_trap = "Stun Trap"

# Misc
extractinator = "Banana Extractinator"
radar = "Cache Detector"

# Tracker
glitched = "UT's Glitched Item"